package com.ruoyi.syzy.service;

import java.util.List;
import com.ruoyi.syzy.domain.BBusiWishUniversitiesEnrollBrochure;

/**
 * 院校招生简章Service接口
 * 
 * @author voluntary
 * @date 2024-09-27
 */
public interface IBBusiWishUniversitiesEnrollBrochureService 
{
    /**
     * 查询院校招生简章
     * 
     * @param id 院校招生简章主键
     * @return 院校招生简章
     */
    public BBusiWishUniversitiesEnrollBrochure selectBBusiWishUniversitiesEnrollBrochureById(Long id);

    /**
     * 查询院校招生简章列表
     * 
     * @param bBusiWishUniversitiesEnrollBrochure 院校招生简章
     * @return 院校招生简章集合
     */
    public List<BBusiWishUniversitiesEnrollBrochure> selectBBusiWishUniversitiesEnrollBrochureList(BBusiWishUniversitiesEnrollBrochure bBusiWishUniversitiesEnrollBrochure);

    /**
     * 新增院校招生简章
     * 
     * @param bBusiWishUniversitiesEnrollBrochure 院校招生简章
     * @return 结果
     */
    public int insertBBusiWishUniversitiesEnrollBrochure(BBusiWishUniversitiesEnrollBrochure bBusiWishUniversitiesEnrollBrochure);

    /**
     * 修改院校招生简章
     * 
     * @param bBusiWishUniversitiesEnrollBrochure 院校招生简章
     * @return 结果
     */
    public int updateBBusiWishUniversitiesEnrollBrochure(BBusiWishUniversitiesEnrollBrochure bBusiWishUniversitiesEnrollBrochure);

    /**
     * 批量删除院校招生简章
     * 
     * @param ids 需要删除的院校招生简章主键集合
     * @return 结果
     */
    public int deleteBBusiWishUniversitiesEnrollBrochureByIds(Long[] ids);

    /**
     * 删除院校招生简章信息
     * 
     * @param id 院校招生简章主键
     * @return 结果
     */
    public int deleteBBusiWishUniversitiesEnrollBrochureById(Long id);

    /**
     * 查询所有类型（去重）
     * 
     * @return 类型列表
     */
    public List<BBusiWishUniversitiesEnrollBrochure> getBrochureTypes();

    /**
     * 导入院校简章数据
     *
     * @param brochureList 院校简章数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importUniversityBrochure(List<BBusiWishUniversitiesEnrollBrochure> brochureList, Boolean isUpdateSupport, String operName);
}
